PI-approximation using the Leibnitz formular:

.. math::

  \frac{\pi}{4} &= \sum\limits_{n=0}^\infty \frac{(-1)^n}{2n+1} \Leftrightarrow \\
  \pi &= 4\sum\limits_{n=0}^\infty \frac{(-1)^n}{2n+1} 
      = 4\sum\limits_{n=0}^\infty (\frac{1}{4n+1} - \frac{1}{4n+3})

